@@ -6,6 +6,9 @@ from collections import defaultdict
 
 from kabaret import flow
 from kabaret.subprocess_manager.flow import RunAction
+from kabaret.flow_entities.entities import Entity, EntityCollection, Property
+
+from ..utils.kabaret.flow_entities.entities import GlobalEntityCollection
 
 from .maputils import ClearMapAction
 from .users import PresetChoiceValue
@@ -270,7 +273,14 @@ class KitsuAPIWrapper(flow.Object):
             ))
             return None
         
-        user_kitsu_id = user.kitsu_id.get()
+        user_kitsu_id = self.get_user_login(project_user_name)
+        
+        if user_kitsu_id is None:
+            self.root().session().log_error((
+                f"No Kitsu login found for user '{project_user_name}'"
+            ))
+            return None
+
         kitsu_user = gazu.person.get_person_by_desktop_login(user_kitsu_id)
         
         if kitsu_user is None:
@@ -492,6 +502,37 @@ class ChangeKitsuUserLogin(flow.Action):
         self._map.touch()
 
 
+# class KitsuShot(Entity):
+
+#     kitsu_shot_names = Property()
+
+
+# class KitsuShots(EntityCollection):
+
+#     @classmethod
+#     def mapped_type(cls):
+#         return KitsuShot
+    
+#     def add_shot(self, shot_oid):
+#         self.get_entity_store().get_collection(self.collection_name()).insert_one(
+#             {'name': self._oid_to_mapped_name(shot_oid)},
+#             {'kitsu_shot_names': []}
+#         )
+    
+#     def _oid_to_mapped_name(self, oid):
+#         return oid.replace('/', '_')[1:]
+
+
+class AbstractKitsuShot:
+
+    def set_task_status(self, task_name, task_status):
+        raise NotImplementedError((
+            'Must set the status of the given task '
+            'of the Kitsu shot entity corresponding '
+            'to this shot object.'
+        ))
+
+
 class KitsuUser(flow.SessionObject):
     
     edit = flow.Child(ChangeKitsuUserLogin)
